@@ -12,11 +12,11 @@ Ixchel::Actions::pkgs :: Handles making sure desired packages are installed as s
 
 =head1 VERSION
 
-Version 0.0.1
+Version 0.1.0
 
 =cut
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.1.0';
 
 =head1 SYNOPSIS
 
@@ -24,6 +24,8 @@ our $VERSION = '0.0.1';
 
     my $results=$ixchel->action(action=>'pkgs', opts=>{}'});
 
+=head1 DESCRIPTION
+
 The modules to be installed are determined by the config.
 
     - .pkgs.latest :: Packages to ensure that are installed and up to date, updating if needed.
@@ -143,11 +145,6 @@ sub action {
 	return $self->{results};
 } ## end sub action
 
-sub help {
-	return 'Install packages specified by the config.
-';
-}
-
 sub short {
 	return 'Install packages specified by the config.';
 }
