@@ -21,11 +21,11 @@ Ixchel::Actions::xeno_build :: Builds and installs stuff based on the supplied h
 
 =head1 VERSION
 
-Version 0.0.1
+Version 0.1.0
 
 =cut
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.1.0';
 
 =head1 SYNOPSIS
 
@@ -391,7 +391,7 @@ sub new {
 	if ( defined( $opts{config} ) ) {
 		$self->{config} = $opts{config};
 	}
-	$self->{template_vars} = $self->{config};
+	$self->{template_vars}{config} = $self->{config};
 
 	if ( defined( $opts{t} ) ) {
 		$self->{t} = $opts{t};
@@ -427,7 +427,7 @@ sub action {
 
 	$self->{results} = {
 		errors => [],
-		status => '',
+		status_text => '',
 		ok     => 0,
 	};
 
@@ -773,7 +773,8 @@ sub action {
 					type   => $type,
 					status => 'Trying to install Perl ' . $module . ' via pkg',
 				);
-				my $returned = perl_module_via_pkg( module => $module );
+				my $returned;
+				eval { perl_module_via_pkg( module => $module ); };
 				# if this fails, set error and return as the module is required to be installed via pkg and we can't
 				if ($returned) {
 					$self->status_add(
@@ -797,7 +798,8 @@ sub action {
 					type   => $type,
 					status => 'Trying to install Perl ' . $module . ' via pkg',
 				);
-				my $returned = perl_module_via_pkg( module => $module );
+				my $returned;
+				eval { $returned = perl_module_via_pkg( module => $module ); };
 				if ($returned) {
 					$self->status_add(
 						type   => $type,
@@ -1025,14 +1027,6 @@ sub action {
 						status => 'exec[' . $command_int . '] command: ' . $command_hash->{command},
 					);
 
-					$self->status_add(
-						type   => $type,
-						status => 'exec['
-							. $command_int
-							. '] ok exits: '
-							. join( ',', @{ $command_hash->{exits} } ),
-					);
-
 					# if requested to template it, process the command and dir
 					if ( $command_hash->{template} ) {
 						eval {
@@ -1047,21 +1041,30 @@ sub action {
 							$self->{t}->process( \$dir, $self->{template_vars}, \$output )
 								|| die $self->{t}->error;
 							$command_hash->{dir} = $output;
+
+							$self->status_add(
+								type   => $type,
+								status => 'exec[' . $command_int . '] Templated: ' . $command_hash->{command},
+							);
 						};
 						if ($@) {
 							$self->status_add(
 								type   => $type,
-								status => 'Templating failed... ' . $@,
+								status => 'exec[' . $command_int . '] Templating failed... ' . $@,
 								error  => 1,
 							);
 							return $self->{results};
 						}
-						$self->status_add(
-							type   => $type,
-							status => 'Templated: ' . $command_hash->{command},
-						);
 					} ## end if ( $command_hash->{template} )
 
+					$self->status_add(
+						type   => $type,
+						status => 'exec['
+							. $command_int
+							. '] ok exits: '
+							. join( ',', @{ $command_hash->{exits} } ),
+					);
+
 					# chdir to the dir specified if needed
 					if ( $command_hash->{dir} ) {
 						eval { chdir( $command_hash->{dir} ); };
@@ -1105,7 +1108,12 @@ sub action {
 							error => 1,
 						);
 						return $self->{results};
-					} ## end if ( !$exit_code_matched )
+					} else {
+						$self->status_add(
+							type   => $type,
+							status => 'exec[' . $command_int . ']  Exit Code: ' . $exit_code,
+						);
+					}
 
 				} ## end if ( defined( $self->{opts}{xeno_build}{$type...}))
 
@@ -1122,15 +1130,6 @@ sub action {
 	return $self->{results};
 } ## end sub action
 
-sub help {
-	return 'Builds/installs stuff based on a passed hash ref.
-
-Not usable directly. Use xeno action.
-
-See perldoc Ixchel::Actions::xeno_build for more details.
-';
-}
-
 sub short {
 	return 'Builds/installs stuff based on a passed hash ref. Not usable directly. Use xeno action.';
 }
@@ -1162,7 +1161,7 @@ sub status_add {
 
 	print $status. "\n";
 
-	$self->{results}{status} = $self->{results}{status} . $status;
+	$self->{results}{status_text} = $self->{results}{status_text} . $status;
 
 	if ( $opts{error} ) {
 		push( @{ $self->{results}{errors} }, $opts{status} );
