@@ -78,21 +78,22 @@ sub get {
 			filestore   => '',
 			ignore      => '',
 			ignoreHosts => '',
-			env_proxy   => 1,
+			env_proxy   => 0,
 			stats_file  => '/var/cache/suricata_extract_submit_stats.json',
 			stats_dir   => '/var/cache/suricata_extract_submit_stats/',
 			interval    => '*/2 * * * *',
 		},
 		sagan => {
-			multi_instance  => 0,
-			config_base     => '/usr/local/etc/',
-			instances       => {},
-			config          => {},
-			rules           => [],
-			instances_rules => {},
-			enable          => 0,
-			base_config     => 'https://raw.githubusercontent.com/quadrantsec/sagan/main/etc/sagan.yaml',
-			rules           => 'https://raw.githubusercontent.com/quadrantsec/sagan-rules/main/rules.yaml'
+			multi_instance      => 0,
+			merged_base_include => 1,
+			config_base         => '/usr/local/etc/',
+			instances           => {},
+			config              => {},
+			rules               => [],
+			instances_rules     => {},
+			enable              => 0,
+			base_config         => 'https://raw.githubusercontent.com/quadrantsec/sagan/main/etc/sagan.yaml',
+			rules               => 'https://raw.githubusercontent.com/quadrantsec/sagan-rules/main/rules.yaml'
 		},
 		meer => {
 			multi_instance => 0,
@@ -216,7 +217,8 @@ sub get {
 			krb5_ccname                   => '',
 			dref                          => '',
 		},
-		snmp => {
+		sneck => { enable => 0, },
+		snmp  => {
 			community         => 'public',
 			extend_env        => 'PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin LC_ALL=C',
 			syslocation       => '',
@@ -243,6 +245,8 @@ sub get {
 				systemd            => { enable => 0, cache => '/var/cache/systemd.extend', use_cache => 1 },
 				mysql              => { enable => 0, host  => '127.0.0.1', port => '3306', ssl => 0, timeout => 0, },
 				sneck              => { enable => 0, },
+				bind               => { enable => 0, },
+				borgbackup         => { enable => 0, },
 				suricata_extract   => { enable => 0, },
 				suricata           => { enable => 0, args => '', },
 				sagan              => { enable => 0, args => '', },
@@ -258,13 +262,15 @@ sub get {
 				squid              => { enable => 0, },
 				ifAlias            => { enable => 0, },
 				ntp_client         => { enable => 0, },
+				mojo_cape_submit   => { enable => 0, },
+				mdadm              => { enable => 0, },
 				logsize            => {
 					enable          => 0,
-					remote          => 1,
+					remote          => 0,
 					remote_sub_dirs => 0,
 					remote_exclude  => [ 'achive', ],
 					suricata_flows  => 1,
-					suricata_base   => 0,
+					suricata_base   => 1,
 					sagan_base      => 0,
 					apache2         => 1,
 					var_log         => 1,
